@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "googletranslator.h"
@@ -33,6 +21,9 @@ GoogleTranslator::GoogleTranslator(QObject *parent)
     : QObject(parent)
     , mNetworkAccessManager(new QNetworkAccessManager(this))
 {
+    mNetworkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+    mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
+    mNetworkAccessManager->enableStrictTransportSecurityStore(true);
     mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
     connect(mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GoogleTranslator::slotTranslateFinished);
 }
@@ -71,7 +62,7 @@ QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(QCombo
     QMap<QString, QMap<QString, QString> > listLanguage;
 
     TranslatorUtil translatorUtil;
-    QList<QPair<QString, QString> > fullListLanguage;
+    QVector<QPair<QString, QString> > fullListLanguage;
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::automatic));
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::en));
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::nl));
@@ -173,7 +164,11 @@ void GoogleTranslator::translate()
     const QNetworkRequest request(url);
 
     QNetworkReply *reply = mNetworkAccessManager->get(request);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), this, &GoogleTranslator::slotError);
+#else
+    connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::errorOccurred), this, &GoogleTranslator::slotError);
+#endif
 }
 
 void GoogleTranslator::slotError(QNetworkReply::NetworkError /*error*/)
