@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "plugininterface.h"
@@ -89,7 +77,7 @@ void PluginInterface::createPluginInterface()
     const auto pluginsList = d->mGenericPluginManager->pluginsList();
     for (PimCommon::GenericPlugin *plugin : pluginsList) {
         if (plugin->isEnabled()) {
-            PimCommon::GenericPluginInterface *interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(this));
+            auto *interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(this));
             interface->setParentWidget(d->mParentWidget);
             //Add parent before creating action
             interface->createAction(d->mActionCollection);
@@ -188,7 +176,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
             PimCommon::ActionType::Type type = actionType.type();
             QList<QAction *> lst = listType.value(type);
             if (!lst.isEmpty()) {
-                QAction *act = new QAction(this);
+                auto *act = new QAction(this);
                 act->setSeparator(true);
                 lst << act << actionType.action();
                 listType.insert(type, lst);
@@ -199,7 +187,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
                 type = PimCommon::ActionType::PopupMenu;
                 lst = listType.value(type);
                 if (!lst.isEmpty()) {
-                    QAction *act = new QAction(this);
+                    auto *act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     listType.insert(type, lst);
@@ -211,7 +199,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
                 type = PimCommon::ActionType::ToolBar;
                 lst = listType.value(type);
                 if (!lst.isEmpty()) {
-                    QAction *act = new QAction(this);
+                    auto *act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     listType.insert(type, lst);
